#[non_exhaustive]pub enum ActiveTurnPolicy {
FinishCurrent {
grace: Duration,
},
Interrupt,
}Expand description
Policy for the turn active when runtime admission closes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FinishCurrent
Let the active turn finish for at most grace, then interrupt it.
Interrupt
Interrupt the active turn immediately through its Session token.