#[non_exhaustive]pub enum RuntimeError {
MissingProvider,
CommandChannelClosed,
RuntimeClosing,
AsyncRuntimeUnavailable,
ActorJoin(JoinError),
Agent(AgentError),
CodingPresetRequiresFeature,
Session(SessionError),
ShutdownIncomplete {
report: ShutdownReport,
},
InvalidShutdownFinalizerRegistry(ShutdownFinalizerRegistryError),
}Expand description
Errors returned by the embeddable runtime facade.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingProvider
The builder cannot create a runtime without a provider.
CommandChannelClosed
A command could not be sent because the runtime actor is closed.
RuntimeClosing
A submission was rejected because the runtime shutdown fence has closed.
Runtime construction requires an active Tokio runtime.
ActorJoin(JoinError)
The runtime actor task failed to join.
Agent(AgentError)
The underlying agent returned an error.
CodingPresetRequiresFeature
The coding preset requires the optional shared-composition feature.
Session(SessionError)
A durable session could not be read or committed.
ShutdownIncomplete
The legacy shutdown wrapper observed incomplete bounded cleanup.
Fields

report: ShutdownReportRedacted structured report describing the incomplete stages.
InvalidShutdownFinalizerRegistry(ShutdownFinalizerRegistryError)
Talos-owned shutdown finalizers could not be frozen safely.