#[non_exhaustive]pub enum ShutdownActiveTurnOutcome {
Idle,
Finished,
InterruptedAndFinalized,
Failed,
Unreconciled,
}Expand description
Redacted outcome for the turn active at the shutdown fence.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Idle
No turn was start-committed at the fence.
Finished
The active turn completed before interruption won.
InterruptedAndFinalized
The existing Session cancellation/finalization path completed.
Failed
The active turn reached an error terminal result.
Unreconciled
The deadline contained the actor before terminal reconciliation was observed.