#[non_exhaustive]pub enum ShutdownFinalizerOutcome {
Completed,
Failed,
Panicked,
TimedOut,
NotRunDeadline,
}Expand description
Redacted terminal outcome for one runtime-owned shutdown finalizer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Completed
The finalizer completed within its cap and the global deadline.
Failed
The finalizer returned its closed failure category.
Panicked
The finalizer task panicked and was contained.
TimedOut
The finalizer exceeded its cap or the remaining global deadline.
NotRunDeadline
The global deadline expired before this finalizer could start.