#[non_exhaustive]pub enum ShutdownOptionsError {
ZeroTotalTimeout,
FinishGraceNotLessThanTotal,
TotalTimeoutOutOfRange,
}Expand description
Validation errors for ShutdownOptions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroTotalTimeout
The total shutdown timeout must be greater than zero.
FinishGraceNotLessThanTotal
Finish grace must leave time inside the total shutdown timeout.
TotalTimeoutOutOfRange
The timeout cannot be represented by the monotonic clock.