pub struct RuntimeHandle { /* private fields */ }Expand description
Handle for interacting with a running embedded Talos runtime.
Implementations
Sourceimpl RuntimeHandle
impl RuntimeHandle
Sourcepub async fn submit(&self, message: impl Into<String>) -> RuntimeResult<()>
pub async fn submit(&self, message: impl Into<String>) -> RuntimeResult<()>
Submits a user message as a new turn.
Sourcepub async fn preview_request(
&self,
message: impl Into<String>,
) -> RuntimeResult<()>
pub async fn preview_request( &self, message: impl Into<String>, ) -> RuntimeResult<()>
Requests a provider request preview without making a provider call.
Sourcepub async fn interrupt(&self) -> RuntimeResult<()>
pub async fn interrupt(&self) -> RuntimeResult<()>
Interrupts the active turn, if any.
Sourcepub async fn next_event(&mut self) -> Option<SessionEvent>
pub async fn next_event(&mut self) -> Option<SessionEvent>
Receives the next runtime event.
Sourcepub fn shutdown_controller(&self) -> RuntimeShutdownHandle
pub fn shutdown_controller(&self) -> RuntimeShutdownHandle
Returns a cloneable controller that can only initiate or join shutdown.
Sourcepub async fn shutdown_with(
&self,
options: ShutdownOptions,
) -> RuntimeResult<ShutdownReport>
pub async fn shutdown_with( &self, options: ShutdownOptions, ) -> RuntimeResult<ShutdownReport>
Starts or joins structured bounded shutdown without consuming the handle.
Sourcepub async fn shutdown(self) -> RuntimeResult<()>
pub async fn shutdown(self) -> RuntimeResult<()>
Shuts down the runtime actor and waits for it to finish.